@@ -32,7 +32,7 @@
 #' The 2 official colors are
 #' \code{maize} (defined as Pantone 122, 
 #' and approximated by RGB 255/223/79, or HEX #FFDF4F), and
-#' \code{blue_carleton} (defined as Pantone 294, 
+#' \code{Carleton blue} (defined as Pantone 294, 
 #' and approximated by RGB 0/48/105, or HEX #003069).
 #'
 #' \code{carleton} uses the HEX color definitions. 
@@ -50,7 +50,7 @@
 #' @examples
 #' carleton
 #' unikn::seecol(carleton, 
-#'               main = "Colors of the University of Carleton") # view color palette
+#'               main = "The colors of the University of Carleton, CA") # view color palette
 #'
 #' @family Canadian university color palettes
 #'
@@ -64,11 +64,11 @@
 #' @export
 
 carleton <- unikn::newpal(col = c("#FFDF4F", "#003069"),
-                          names = c("maize", "blue_carleton"),
+                          names = c("maize", "Carleton blue"),
                           as_df = FALSE)
 
 # # Check: 
-## unikn::seecol(carleton, main = "Official colors of the University of Carleton", col_bg = "white")
+## unikn::seecol(carleton, main = "Official colors of the University of Carleton, CA", col_bg = "white")
 
 
 
