@@ -1,4 +1,4 @@
-## Dartmouth.R | 2023 07 22
+## Dartmouth.R | 2023 09 24
 ## Colors of Dartmouth College, USA
 ## --------------------------------
 
@@ -6,6 +6,7 @@
 
 # cur_pals: "dartmouth_1", "dartmouth_2", "dartmouth_3" (3)
 # inst: "Dartmouth College" 
+# inst_alt: "Dartmouth" 
 # country: USA
 # URL: "https://home.dartmouth.edu"
 
@@ -23,7 +24,7 @@
 #' of \href{https://home.dartmouth.edu}{Dartmouth College}, USA.
 #'
 #' The primary color is
-#' \code{"dartmouth_green"} (defined as HEX #00693E). 
+#' \code{"Dartmouth green"} (defined as HEX #00693E). 
 #'
 #' \code{dartmouth_1} uses the HEX color definitions.
 #'
@@ -34,18 +35,18 @@
 #' \strong{unicol}, 2023-07-13.
 #'
 #' @source
-#' Color definitions are based on 
-#' \href{https://communications.dartmouth.edu/visual-identity/design-elements/color-palette}{Dartmouth's visual identity guide}.
+#' Color definitions are based on \href{https://home.dartmouth.edu}{Dartmouth}'s 
+#' \href{https://communications.dartmouth.edu/visual-identity/design-elements/color-palette}{visual identity guide}.
 #'
 #' @examples
 #' dartmouth_1
-#' unikn::seecol(dartmouth_1, main = "Dartmouth College 1") # view color palette.
+#' unikn::seecol(dartmouth_1, main = "Primary color of Dartmouth College") # view palette
 #'
 #' @family U.S. university color palettes
 #'
 #' @seealso
-#' \code{\link{dartmouth_2}} for the secondary colors of Dartmouth College; 
-#' \code{\link{dartmouth_3}} for the tertiary colors of Dartmouth College; 
+#' \code{\link{dartmouth_2}} for secondary colors of Dartmouth College; 
+#' \code{\link{dartmouth_3}} for tertiary colors of Dartmouth College; 
 #' \code{\link{seecol}} for viewing and comparing color palettes;
 #' \code{\link{usecol}} for using color palettes;
 #' \code{\link{simcol}} for finding similar colors;
@@ -55,7 +56,7 @@
 #' @export
 
 dartmouth_1 <- unikn::newpal(col = c("#00693E"), 
-                             names = c("dartmouth_green"), 
+                             names = c("Dartmouth green"), 
                              as_df = FALSE)
 
 
@@ -66,17 +67,17 @@ dartmouth_1 <- unikn::newpal(col = c("#00693E"),
 #' Secondary colors of Dartmouth College, USA 
 #' 
 #' \code{dartmouth_2} provides the eight secondary colors
-#' of the \href{https://home.dartmouth.edu}{Dartmouth College}, USA.
+#' of \href{https://home.dartmouth.edu}{Dartmouth College}, USA.
 #' 
 #' The 8 secondary colors are 
-#' \code{"forest_green"} (defined as HEX #12312b),
-#' \code{"rich_forest_green"} (defined as HEX #0D1E1C),
-#' \code{"snow_white"} (defined as HEX #ffffff),
-#' \code{"midnight_black"} (defined as HEX #000000)
-#' \code{"web_gray_1"} (defined as HEX #f7f7f7)
-#' \code{"web_gray_2"} (defined as HEX #e2e2e2)
-#' \code{"web_gray_3"} (defined as HEX #707070)
-#' \code{"granite_gray"} (defined as HEX #424141)
+#' \code{"forest green"} (defined as HEX #12312b),
+#' \code{"rich forest green"} (defined as HEX #0D1E1C),
+#' \code{"snow white"} (identical to \code{"white"} and defined as HEX #ffffff),
+#' \code{"midnight black"} (defined as HEX #000000)
+#' \code{"web gray 1"} (defined as HEX #f7f7f7)
+#' \code{"web gray 2"} (defined as HEX #e2e2e2)
+#' \code{"web gray 3"} (defined as HEX #707070), and 
+#' \code{"granite gray"} (defined as HEX #424141). 
 #' 
 #' \code{dartmouth_2} uses the HEX color definitions.
 #' 
@@ -87,18 +88,18 @@ dartmouth_1 <- unikn::newpal(col = c("#00693E"),
 #' \strong{unicol}, 2320-07-13.
 #' 
 #' @source 
-#' Color definitions are based on 
-#' \href{https://communications.dartmouth.edu/visual-identity/design-elements/color-palette}{Dartmouth's visual identity guide}.
+#' Color definitions are based on \href{https://home.dartmouth.edu}{Dartmouth}'s 
+#' \href{https://communications.dartmouth.edu/visual-identity/design-elements/color-palette}{visual identity guide}. 
 #'
 #' @examples 
 #' dartmouth_2
-#' unikn::seecol(dartmouth_2, main = "Dartmouth College 2") # view color palette
+#' unikn::seecol(dartmouth_2, main = "Secondary colors of Dartmouth College")  # view palette
 #' 
 #' @family U.S. university color palettes
 #'
 #' @seealso 
-#' \code{\link{dartmouth_1}} for the primary color of Dartmouth College;
-#' \code{\link{dartmouth_3}} for the tertiary colors of Dartmouth College; 
+#' \code{\link{dartmouth_1}} for primary color of Dartmouth College;
+#' \code{\link{dartmouth_3}} for tertiary colors of Dartmouth College; 
 #' \code{\link{seecol}} for viewing and comparing color palettes;
 #' \code{\link{usecol}} for using color palettes;
 #' \code{\link{simcol}} for finding similar colors;
@@ -109,8 +110,8 @@ dartmouth_1 <- unikn::newpal(col = c("#00693E"),
 
 dartmouth_2 <- unikn::newpal(col = c("#12312b", "#0D1E1C", "#ffffff", "#000000", 
                                      "#f7f7f7", "#e2e2e2", "#707070", "#424141"), 
-                             names = c("forest_green", "rich_forest_green","snow_white", "midnight_black", 
-                                       "web_gray_1", "web_gray_2", "web_gray_3", "granite_gray"), 
+                             names = c("forest green", "rich forest green","snow white", "midnight black", 
+                                       "web gray 1", "web gray 2", "web gray 3", "granite gray"), 
                              as_df = FALSE)
 
 
@@ -120,19 +121,19 @@ dartmouth_2 <- unikn::newpal(col = c("#12312b", "#0D1E1C", "#ffffff", "#000000",
 #' Tertiary colors of Dartmouth College, USA 
 #' 
 #' \code{dartmouth_3} provides the ten tertiary colors
-#' of the \href{https://home.dartmouth.edu}{Dartmouth College}, USA.
+#' of \href{https://home.dartmouth.edu}{Dartmouth College}, USA.
 #' 
 #' The 10 tertiary colors are 
-#' \code{"autumn_brown"} (defined as HEX #643c20), 
-#' \code{"bonfire_red"} (defined as HEX #9d162e), 
-#' \code{"tuck_orange"} (defined as HEX #e32d1c), 
-#' \code{"summer_yellow"} (defined as HEX #f5dc96), 
-#' \code{"spring_green"} (defined as HEX #c4dd88), 
-#' \code{"rich_spring_green"} (defined as HEX #a5d75f), 
-#' \code{"river_navy"} (defined as HEX #003c73), 
-#' \code{"river_blue"} (defined as HEX #267aba), 
-#' \code{"web_violet"} (defined as HEX #8a6996), and 
-#' \code{"bonfire_orange"} (defined as HEX #ffa00f). 
+#' \code{"autumn brown"} (defined as HEX #643c20), 
+#' \code{"bonfire red"} (defined as HEX #9d162e), 
+#' \code{"tuck orange"} (defined as HEX #e32d1c), 
+#' \code{"summer yellow"} (defined as HEX #f5dc96), 
+#' \code{"spring green"} (defined as HEX #c4dd88), 
+#' \code{"rich spring green"} (defined as HEX #a5d75f), 
+#' \code{"river navy"} (defined as HEX #003c73), 
+#' \code{"river blue"} (defined as HEX #267aba), 
+#' \code{"web violet"} (defined as HEX #8a6996), and 
+#' \code{"bonfire orange"} (defined as HEX #ffa00f). 
 #' 
 #' \code{dartmouth_3} uses the HEX color definitions.
 #' 
@@ -148,13 +149,13 @@ dartmouth_2 <- unikn::newpal(col = c("#12312b", "#0D1E1C", "#ffffff", "#000000",
 #'
 #' @examples 
 #' dartmouth_3
-#' unikn::seecol(dartmouth_3, main = "Dartmouth College 3") # view color palette
+#' unikn::seecol(dartmouth_3, main = "Tertiary colors of Dartmouth College") # view palette
 #' 
 #' @family U.S. university color palettes
 #'
 #' @seealso 
-#' \code{\link{dartmouth_1}} for the primary color of Dartmouth College; 
-#' \code{\link{dartmouth_3}} for the tertiary colors of Dartmouth College; 
+#' \code{\link{dartmouth_1}} for primary color of Dartmouth College; 
+#' \code{\link{dartmouth_3}} for tertiary colors of Dartmouth College; 
 #' \code{\link{seecol}} for viewing and comparing color palettes;
 #' \code{\link{usecol}} for using color palettes;
 #' \code{\link{simcol}} for finding similar colors;
@@ -165,8 +166,8 @@ dartmouth_2 <- unikn::newpal(col = c("#12312b", "#0D1E1C", "#ffffff", "#000000",
 
 dartmouth_3 <- unikn::newpal(col = c("#643c20", "#9d162e", "#e32d1c", "#f5dc96", "#c4dd88", 
                                      "#a5d75f", "#003c73", "#267aba", "#8a6996", "#ffa00f"), 
-                             names = c("autumn_brown", "bonfire_red", "tuck_orange", "summer_yellow", "spring_green", 
-                                       "rich_spring_green", "river_navy", "river_blue", "web_violet", "bonfire_orange"), 
+                             names = c("autumn brown", "bonfire red", "tuck orange", "summer yellow", "spring green", 
+                                       "rich spring green", "river navy", "river blue", "web violet", "bonfire orange"), 
                              as_df = FALSE)
 
 ## ToDo:---
