@@ -23,8 +23,8 @@
 #' of the \href{https://www.nd.edu}{University of Notre Dame}, USA.
 #'
 #' The 2 primary colors are
-#' \code{"nd_blue"} (defined as HEX #0c2340) and 
-#' \code{"nd_metallic_gold"} (defined as HEX #ae9142). 
+#' \code{"ND blue"} (defined as HEX #0c2340) and 
+#' \code{"ND metallic gold"} (defined as HEX #ae9142). 
 #'
 #' \code{notredame_1} uses the HEX color definitions.
 #'
@@ -35,8 +35,8 @@
 #' \strong{unicol}, 2023-07-16.
 #'
 #' @source
-#' Color definitions are based on 
-#' \href{https://onmessage.nd.edu/university-branding/colors/}{ND's website}.
+#' Color definitions are based on \href{https://www.nd.edu}{Notre Dame}'s
+#' \href{https://onmessage.nd.edu/university-branding/colors/}{branding site}.
 #'
 #' @examples
 #' notredame_1
@@ -55,7 +55,7 @@
 #' @export
 
 notredame_1 <- unikn::newpal(col = c("#0c2340", "#ae9142"), 
-                             names = c("nd_blue", "nd_metallic_gold"), 
+                             names = c("ND blue", "ND metallic gold"), 
                              as_df = FALSE)
 
 
@@ -67,17 +67,17 @@ notredame_1 <- unikn::newpal(col = c("#0c2340", "#ae9142"),
 #' of the \href{https://www.nd.edu}{University of Notre Dame}, USA.
 #' 
 #' The 11 secondary colors are 
-#' \code{"brand_blue_light"} (defined as HEX #143865),
-#' \code{"brand_blue_bright"} (defined as HEX #1c4f8f),
-#' \code{"brand_gold_dark"} (defined as HEX #8c7535),
-#' \code{"brand_gold_light"} (defined as HEX #d39f10), 
-#' \code{"sky_blue"} (defined as HEX #e1e8f2), 
-#' \code{"sky_blue_dark"} (defined as HEX #c1cddd), 
-#' \code{"sky_blue_light"} (defined as HEX #edf2f9), 
-#' \code{"warm_white"} (defined as HEX #f8f4ec), 
-#' \code{"warm_white_dark"} (defined as HEX #efe9d9), 
-#' \code{"brand_green"} (defined as HEX #0a843d), and 
-#' \code{"brand_green_light"} (defined as HEX #b3dac5).
+#' \code{"Brand blue light"} (defined as HEX #143865),
+#' \code{"Brand blue bright"} (defined as HEX #1c4f8f),
+#' \code{"Brand gold dark"} (defined as HEX #8c7535),
+#' \code{"Brand gold light"} (defined as HEX #d39f10), 
+#' \code{"Sky blue"} (defined as HEX #e1e8f2), 
+#' \code{"Sky blue dark"} (defined as HEX #c1cddd), 
+#' \code{"Sky blue light"} (defined as HEX #edf2f9), 
+#' \code{"Warm white"} (defined as HEX #f8f4ec), 
+#' \code{"Warm white dark"} (defined as HEX #efe9d9), 
+#' \code{"Brand green"} (defined as HEX #0a843d), and 
+#' \code{"Brand green light"} (defined as HEX #b3dac5).
 #' 
 #' \code{notredame_2} uses the HEX color definitions.
 #' 
@@ -88,8 +88,8 @@ notredame_1 <- unikn::newpal(col = c("#0c2340", "#ae9142"),
 #' \strong{unicol}, 2320-07-16.
 #' 
 #' @source 
-#' Color definitions are based on 
-#' \href{https://onmessage.nd.edu/university-branding/colors/}{ND's website}.
+#' Color definitions are based on \href{https://www.nd.edu}{Notre Dame}'s
+#' \href{https://onmessage.nd.edu/university-branding/colors/}{branding site}.
 #'
 #' @examples 
 #' notredame_2
@@ -112,11 +112,11 @@ notredame_2 <- unikn::newpal(col = c("#143865", "#1c4f8f",
                                      "#e1e8f2", "#c1cddd", "#edf2f9", 
                                      "#f8f4ec", "#efe9d9", 
                                      "#0a843d", "#b3dac5"), 
-                             names = c("brand_blue_light", "brand_blue_bright", 
-                                       "brand_gold_dark", "brand_gold_light", 
-                                       "sky_blue", "sky_blue_dark", "sky_blue_light", 
-                                       "warm_white", "warm_white_dark", 
-                                       "brand_green", "brand_green_light"), 
+                             names = c("Brand blue light", "Brand blue bright", 
+                                       "Brand gold dark", "Brand gold light", 
+                                       "Sky blue", "Sky blue dark", "Sky blue light", 
+                                       "Warm white", "Warm white dark", 
+                                       "Brand green", "Brand green light"), 
                              as_df = FALSE)
 
 
