@@ -1,4 +1,4 @@
-## York University.R | 2023 08 24
+## York University.R | 2023 09 23
 ## Colors of York University, Canada
 ## ---------------------------------
 
@@ -12,7 +12,7 @@
 
 # Color source:
 
-# URL: <https://www.yorku.ca/brand/wp-content/uploads/sites/18/2021/07/YORKU_Brand_Standards_July2021.pdf>
+# URL: <https://www.yorku.ca/brand/>
 # Last check: 2023-06-24
 
 
@@ -20,16 +20,15 @@
 
 # Color palette(s):
 
-
 # - yorku_1: Primary colors of York University ------
 
 #' Primary colors of the York University, Canada  
 #'
 #' \code{yorku_1} provides the three primary colors 
-#' of the \href{https://www.yorku.ca/}{York University}, Canada.
+#' of the \href{https://www.yorku.ca}{York University}, Canada.
 #'
 #' The 3 primary colors are
-#' \code{"york_red"} (defined as RGB 227/24/55, HEX #E31837),
+#' \code{"York red"} (defined as RGB 227/24/55, HEX #E31837),
 #' \code{"white"} (defined as RGB 255/255/255, HEX #FFFFFF), and
 #' \code{"black"} (defined as RGB 0/0/0, HEX #000000).
 #' 
@@ -42,12 +41,13 @@
 #' \strong{unicol}, 2023-06-24.
 #'
 #' @source 
-#' Color definitions are based on the
-#' \href{https://www.yorku.ca/brand/wp-content/uploads/sites/18/2021/07/YORKU_Brand_Standards_July2021.pdf}{York Brand Standards (PDF)}.
+#' Color definitions are based on \href{https://www.yorku.ca}{York}'s 
+#' \href{https://www.yorku.ca/brand/}{Brand standards} (PDF).
 #'
 #' @examples
 #' yorku_1
-#' unikn::seecol(yorku_1, main = "Primary colors of York University") # view color palette
+#' unikn::seecol(yorku_1, col_bg = "grey90", 
+#'               main = "The primary colors of York University, CA") # view palette
 #'
 #' @family Canadian university color palettes
 #'
@@ -61,7 +61,7 @@
 #' @export
 
 yorku_1 <- unikn::newpal(col = c("#E31837", "#FFFFFF", "#000000"),
-                         names = c("york_red", "white", "black"),
+                         names = c("York red", "white", "black"),
                          as_df = FALSE)
 
 # - yorku_2: Secondary colors of York University ------
@@ -69,17 +69,17 @@ yorku_1 <- unikn::newpal(col = c("#E31837", "#FFFFFF", "#000000"),
 #' Secondary colors of the York University, Canada  
 #'
 #' \code{yorku_2} provides eight secondary colors 
-#' of the \href{https://www.yorku.ca/}{York University}, Canada.
+#' of the \href{https://www.yorku.ca}{York University}, Canada.
 #'
 #' The 8 secondary colors are: 
-#' \code{"york_red_medium"}  (defined as RGB 175/13/26,   HEX #AF0D1A),
-#' \code{"york_red_dark"}    (defined as RGB 129/0/1,     HEX #810001),
-#' \code{"york_bright_blue"} (defined as RGB 58/194/239,  HEX #3AC2EF),
-#' \code{"york_light_blue"}  (defined as RGB 172/230/248, HEX #ACE6F8),
-#' \code{"york_light_grey"}  (defined as RGB 225/223/220, HEX #E1DFDC),
-#' \code{"york_pewter"}      (defined as RGB 214/207/202, HEX #D6CFCA),
-#' \code{"york_grey_medium"} (defined as RGB 183/174/169, HEX #B7AEA9), and
-#' \code{"york_grey_dark"}   (defined as RGB 104/98/96,   HEX #686260).
+#' \code{"York red medium"}  (defined as RGB 175/13/26,   HEX #AF0D1A),
+#' \code{"York red dark"}    (defined as RGB 129/0/1,     HEX #810001),
+#' \code{"York bright blue"} (defined as RGB 58/194/239,  HEX #3AC2EF),
+#' \code{"York light blue"}  (defined as RGB 172/230/248, HEX #ACE6F8),
+#' \code{"York light grey"}  (defined as RGB 225/223/220, HEX #E1DFDC),
+#' \code{"York pewter"}      (defined as RGB 214/207/202, HEX #D6CFCA),
+#' \code{"York grey medium"} (defined as RGB 183/174/169, HEX #B7AEA9), and
+#' \code{"York grey dark"}   (defined as RGB 104/98/96,   HEX #686260).
 #' 
 #' \code{yorku_2} uses the HEX color definitions. 
 #' 
@@ -90,12 +90,12 @@ yorku_1 <- unikn::newpal(col = c("#E31837", "#FFFFFF", "#000000"),
 #' \strong{unicol}, 2023-06-24.
 #'
 #' @source 
-#' Color definitions are based on the
-#' \href{https://www.yorku.ca/brand/wp-content/uploads/sites/18/2021/07/YORKU_Brand_Standards_July2021.pdf}{York Brand Standards (PDF)}.
+#' Color definitions are based on \href{https://www.yorku.ca}{York}'s 
+#' \href{https://www.yorku.ca/brand/}{Brand standards} (PDF). 
 #'
 #' @examples
 #' yorku_2
-#' unikn::seecol(yorku_2, main = "York University 2") # view color palette
+#' unikn::seecol(yorku_2, main = "Secondary colors of York University, CA")  # view palette
 #'
 #' @family Canadian university color palettes
 #'
@@ -110,8 +110,8 @@ yorku_1 <- unikn::newpal(col = c("#E31837", "#FFFFFF", "#000000"),
 
 yorku_2 <- unikn::newpal(col = c("#AF0D1A", "#810001", "#3AC2EF", "#ACE6F8", 
                                  "#E1DFDC", "#D6CFCA", "#B7AEA9", "#686260"),
-                         names = c("york_red_medium", "york_red_dark", "bright_blue", "york_light_blue", 
-                                   "york_light_grey", "york_pewter", "york_grey_medium", "york_grey_dark"),
+                         names = c("York red medium", "York red dark", "bright blue", "York light blue", 
+                                   "York light grey", "York pewter", "York grey medium", "York grey dark"),
                          as_df = FALSE)
 
 
